<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0">
<context>
    <name></name>
    <message>
        <source>UNKNOWN CUT</source>
        <translation type="obsolete">Unbekannter Cut</translation>
    </message>
</context>
<context>
    <name>@default</name>
    <message>
        <source>ALL</source>
        <translation type="obsolete">ALLE</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>Couldn&apos;t initialize QSql driver!</source>
        <translation type="obsolete">Nepodařilo se inicializovat ovladač QSql!</translation>
    </message>
    <message>
        <source>Couldn&apos;t open mySQL connection!</source>
        <translation type="obsolete">Nepodařilo se vytvořit žádné spojení se serverem mySQL-Server!</translation>
    </message>
    <message>
        <source>Sequentially</source>
        <translation>Postupně</translation>
    </message>
    <message>
        <source>Randomly</source>
        <translation>Náhodně</translation>
    </message>
    <message>
        <source>Unknown</source>
        <translation>Neznámý</translation>
    </message>
    <message>
        <source>Feature</source>
        <translation>Vlastnost</translation>
    </message>
    <message>
        <source>Theme Open</source>
        <translation>Začátek tématu</translation>
    </message>
    <message>
        <source>Theme Close</source>
        <translation>Konec tématu</translation>
    </message>
    <message>
        <source>Theme Open/Close</source>
        <translation>Začátek/Konec tématu</translation>
    </message>
    <message>
        <source>Background</source>
        <translation>Pozadí</translation>
    </message>
    <message>
        <source>Commercial/Jingle/Promo</source>
        <translation>Komerční/Znělka/Reklama</translation>
    </message>
    <message>
        <source>UNKNOWN CUT</source>
        <translation>Neznámý záběr</translation>
    </message>
    <message>
        <source>Manual</source>
        <translation>Ruční</translation>
    </message>
    <message>
        <source>Play</source>
        <translation>Přehrát</translation>
    </message>
    <message>
        <source>Segue</source>
        <translation>Přechod</translation>
    </message>
    <message>
        <source>Time</source>
        <translation>Čas</translation>
    </message>
    <message>
        <source>Panel</source>
        <translation>Panel</translation>
    </message>
    <message>
        <source>Macro</source>
        <translation>Makro</translation>
    </message>
    <message>
        <source>PLAY</source>
        <translation>PŘEHRÁT</translation>
    </message>
    <message>
        <source>SEGUE</source>
        <translation>PŘECHOD</translation>
    </message>
    <message>
        <source>STOP</source>
        <translation>ZASTAVIT</translation>
    </message>
    <message>
        <source>UNKNOWN</source>
        <translation>NEZNÁMÝ</translation>
    </message>
    <message>
        <source>Audio</source>
        <translation>Poslech</translation>
    </message>
    <message>
        <source>Marker</source>
        <translation>Značka</translation>
    </message>
    <message>
        <source>Open Bracket</source>
        <translation>Otevřít závorku</translation>
    </message>
    <message>
        <source>Close Bracket</source>
        <translation>Zavřít závorku</translation>
    </message>
    <message>
        <source>ChainTo</source>
        <translation type="obsolete">ŘetězDo</translation>
    </message>
    <message>
        <source>Track</source>
        <translation>Stopa</translation>
    </message>
    <message>
        <source>Link</source>
        <translation type="obsolete">Propojení</translation>
    </message>
    <message>
        <source>Traffic</source>
        <translation>Přenos</translation>
    </message>
    <message>
        <source>Music</source>
        <translation>Hudba</translation>
    </message>
    <message>
        <source>RDLogManager</source>
        <translation>RDLogManager</translation>
    </message>
    <message>
        <source>Tracker</source>
        <translation>Tracker</translation>
    </message>
    <message>
        <source>Recording</source>
        <translation>Nahrávání</translation>
    </message>
    <message>
        <source>Macro Event</source>
        <translation>Událost Makro</translation>
    </message>
    <message>
        <source>Switch Event</source>
        <translation>Událost přepnutí</translation>
    </message>
    <message>
        <source>Playout</source>
        <translation>Přehrávat</translation>
    </message>
    <message>
        <source>Download</source>
        <translation>Stáhnout</translation>
    </message>
    <message>
        <source>Upload</source>
        <translation>Nahrát</translation>
    </message>
    <message>
        <source>Ok</source>
        <translation>OK</translation>
    </message>
    <message>
        <source>Short Length</source>
        <translation>Krátká délka</translation>
    </message>
    <message>
        <source>Low Level</source>
        <translation>Nízká úroveň</translation>
    </message>
    <message>
        <source>High Level</source>
        <translation>Vysoká úroveň</translation>
    </message>
    <message>
        <source>Downloading</source>
        <translation>Stahování</translation>
    </message>
    <message>
        <source>Uploading</source>
        <translation>Nahrávání</translation>
    </message>
    <message>
        <source>Server Error</source>
        <translation>Chyba serveru</translation>
    </message>
    <message>
        <source>Internal Error</source>
        <translation>Vnitřní chyba</translation>
    </message>
    <message>
        <source>Interrupted</source>
        <translation>Přerušeno</translation>
    </message>
    <message>
        <source>Playing</source>
        <translation>Přehrává se</translation>
    </message>
    <message>
        <source>Waiting</source>
        <translation>Čeká se</translation>
    </message>
    <message>
        <source>Device Busy</source>
        <translation>Zařízení zaneprázdněno</translation>
    </message>
    <message>
        <source>No Such Cart/Cut</source>
        <translation>Žádný takový vozík/záběr</translation>
    </message>
    <message>
        <source>Unknown Audio Format</source>
        <translation>Neznámý formát zvuku</translation>
    </message>
    <message>
        <source>CBSI DeltaFlex Traffic Reconciliation v2.01</source>
        <translation>CBSI DeltaFlex sladění přenosu v2.01</translation>
    </message>
    <message>
        <source>Text Log</source>
        <translation>Textový zápis</translation>
    </message>
    <message>
        <source>ASCAP/BMI Electronic Music Report</source>
        <translation>ASCAP/BMI elektronická zpráva o hudbě</translation>
    </message>
    <message>
        <source>Technical Playout Report</source>
        <translation>Technická zpráva o přehrávání</translation>
    </message>
    <message>
        <source>SoundExchange Statutory License Report</source>
        <translation>SoundExchange Statutory License Report</translation>
    </message>
    <message>
        <source>RadioTraffic.com Traffic Reconciliation</source>
        <translation>RadioTraffic.com sladění přenosu</translation>
    </message>
    <message>
        <source>VisualTraffic Reconciliation</source>
        <translation>VisualTraffic sladění</translation>
    </message>
    <message>
        <source>CounterPoint Traffic Reconciliation</source>
        <translation>CounterPoint sladění přenosu</translation>
    </message>
    <message>
        <source>Music1 Reconciliation</source>
        <translation>Music1 sladění</translation>
    </message>
    <message>
        <source>Other</source>
        <translation>Jiné</translation>
    </message>
    <message>
        <source>AM</source>
        <translation>AM</translation>
    </message>
    <message>
        <source>FM</source>
        <translation>FM</translation>
    </message>
    <message>
        <source>Report complete!</source>
        <translation>Zpráva úplná!</translation>
    </message>
    <message>
        <source>Report canceled!</source>
        <translation>Zpráva zrušena!</translation>
    </message>
    <message>
        <source>Unable to open report file!</source>
        <translation>Nelze otevřít soubor se zprávou!</translation>
    </message>
    <message>
        <source>invalid SQL or failed DB connection:</source>
        <translation type="obsolete">Neplatné SQL nebo nepodařilo připojit k DB:</translation>
    </message>
    <message>
        <source>Music Summary</source>
        <translation>Hudební shrnutí</translation>
    </message>
    <message>
        <source>WideOrbit Traffic Reconciliation</source>
        <translation>WideOrbit sladění přenosu</translation>
    </message>
    <message>
        <source>Unknown Position</source>
        <translation>Neznámá poloha</translation>
    </message>
    <message>
        <source>Top Left</source>
        <translation>Nahoře vlevo</translation>
    </message>
    <message>
        <source>Top Center</source>
        <translation>Nahoře ve středu</translation>
    </message>
    <message>
        <source>Top Right</source>
        <translation>Nahoře vpravo</translation>
    </message>
    <message>
        <source>Bottom Left</source>
        <translation>Dole vlevo</translation>
    </message>
    <message>
        <source>Bottom Center</source>
        <translation>Dole ve středu</translation>
    </message>
    <message>
        <source>Bottom Right</source>
        <translation>Dole vpravo</translation>
    </message>
    <message>
        <source>NPR/DS SoundExchange Report</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Music Playout</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Main Log Output 1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Main Log Output 2</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Sound Panel First Play Output</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Aux Log 1 Output</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Aux Log 2 Output</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Sound Panel Second Play Output</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Sound Panel Third Play Output</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Sound Panel Fourth Play Output</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Audition/Cue Output</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Channel</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Sound Panel Fifth and Later Play Output</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>invalid SQL or failed DB connection</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>All</source>
        <translation type="unfinished">Vše</translation>
    </message>
    <message>
        <source>Relative</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Hard</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>NaturalLog Reconciliation</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>LiveAssist</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Automatic</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Previous</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Classical Music Playout</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>reserved</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Mr. Master Reconciliation</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Spin Count</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Cut Log</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>unknown</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>feature</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>open</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>close</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>theme</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>background</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>promo</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>cold</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>fade</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>NoTime</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>MusicLink</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>TrafficLink</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Chain</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>new cart</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>cart</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Host already exists!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>host already exists</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>service already exists</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>template service</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>does not exist</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>template host</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Cut</source>
        <translation type="unfinished">Záběr</translation>
    </message>
    <message>
        <source>Log already exists!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>OK</source>
        <translation type="unfinished">OK</translation>
    </message>
    <message>
        <source>No such service!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>No such group</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>No free cart available in group</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Unable to open database</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>is</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Database version mismatch, should be</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Rule broken: Max. in a Row/Min. Wait for </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Rule broken: Do not schedule </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>after</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Rule broken: Do not schedule</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>is overscheduled by</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>is underscheduled by</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>is not playable</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Couldn&apos;t initialize MySql driver!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Couldn&apos;t open MySQL connection on</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>DB connection re-established</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Could not re-establish DB connection</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Unknown error</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Invalid arguments specified</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Specified configuration was not found</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>One or more Rivendell modules are active</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>No running as root</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>systemctl(8) crashed</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Rivendell service shutdown failed</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Audio store unmount failed</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Audio store mount failed</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Rivendell service startup failed</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Current configuration was not found</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Synlink creation failed</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Invalid configuration name</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>mount(8) crashed</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>This host</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>does not have a Hosts entry in the database.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Open RDAdmin-&gt;ManageHosts-&gt;Add to create one.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Unable to update automounter configuration</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>PCM8</source>
        <translation type="unfinished">PCM8</translation>
    </message>
    <message>
        <source>PCM16</source>
        <translation type="unfinished">PCM16</translation>
    </message>
    <message>
        <source>Float32</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>MPEG Layer I</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>MPEG Layer II (MP2)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>MPEG Layer III (MP3)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Dolby AC2</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Dolby AC3</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>OggVorbis</source>
        <translation type="unfinished">OggVorbis</translation>
    </message>
    <message>
        <source>PCM24</source>
        <translation type="unfinished">PCM24</translation>
    </message>
    <message>
        <source>RIFF/WAVE</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Raw MPEG Bitstream</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Ogg Bitstream</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>ATX</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>TMC</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Raw FLAC Bitstream</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>AM-BOS Hybrid</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>AIFF</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>MP4</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Rule broken: Title separation</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source> with sched code(s): </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Rule broken: Artist separation</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>No carts found in group</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>-- End of List --</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>RDAddCart</name>
    <message>
        <source>&amp;Group:</source>
        <translation>&amp;Skupina:</translation>
    </message>
    <message>
        <source>&amp;New Cart Number:</source>
        <translation>&amp;Nové číslo vozíku:</translation>
    </message>
    <message>
        <source>&amp;New Cart Type:</source>
        <translation>&amp;Nový typ vozíku:</translation>
    </message>
    <message>
        <source>Audio</source>
        <translation>Poslech</translation>
    </message>
    <message>
        <source>Macro</source>
        <translation>Makro</translation>
    </message>
    <message>
        <source>[new cart]</source>
        <translation>[nový vozík]</translation>
    </message>
    <message>
        <source>&amp;New Cart Title:</source>
        <translation>&amp;Nový název vozíku:</translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation>&amp;OK</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation>&amp;Zrušit</translation>
    </message>
    <message>
        <source>No Available Cart Numbers</source>
        <translation>Není dostupné žádné číslo vozíku</translation>
    </message>
    <message>
        <source>There are no more available cart numbers for the group!</source>
        <translation>Ve skupině nejsou dostupná žádná další čísla vozíků!</translation>
    </message>
    <message>
        <source>Invalid Number</source>
        <translation>Neplatné číslo</translation>
    </message>
    <message>
        <source>Invalid Cart Number!</source>
        <translation>Neplatné číslo vozíku!</translation>
    </message>
    <message>
        <source>Title Required</source>
        <translation>Název vyžadován</translation>
    </message>
    <message>
        <source>You must enter a cart title!</source>
        <translation>Musíte zadat název vozíku!</translation>
    </message>
    <message>
        <source>The cart number is outside of the permitted range for this group!</source>
        <translation>Číslo vozíku se nachází mimo pro tuto skupinu povolený rozsah!</translation>
    </message>
    <message>
        <source>Cart Exists</source>
        <translation>Vozík existuje</translation>
    </message>
    <message>
        <source>This cart already exists.</source>
        <translation>Tento vozík již existuje.</translation>
    </message>
    <message>
        <source>Duplicate Title</source>
        <translation>Zdvojený název</translation>
    </message>
    <message>
        <source>The cart title must be unique!</source>
        <translation>Název vozíku musí být jedinečný!</translation>
    </message>
    <message>
        <source>Add Cart</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>RDAddLog</name>
    <message>
        <source>Create Log</source>
        <translation>Vytvořit zápis</translation>
    </message>
    <message>
        <source>&amp;New Log Name:</source>
        <translation>&amp;Název nového zápisu:</translation>
    </message>
    <message>
        <source>&amp;Service:</source>
        <translation>&amp;Služba: </translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation>&amp;OK</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation>&amp;Zrušit</translation>
    </message>
    <message>
        <source>RDLogEdit</source>
        <translation>RDLogedit</translation>
    </message>
    <message>
        <source>The name is invalid!</source>
        <translation type="obsolete">Název je neplatný!</translation>
    </message>
    <message>
        <source>The service is invalid!</source>
        <translation>Služba je neplatná!</translation>
    </message>
</context>
<context>
    <name>RDApplication</name>
    <message>
        <source>OK</source>
        <translation type="unfinished">OK</translation>
    </message>
    <message>
        <source>systemctl(1) crashed.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>systemctl(1) returned exit code</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Rivendell service is not active.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>RDAudioSettingsDialog</name>
    <message>
        <source>Edit Settings</source>
        <translation type="obsolete">Upravit nastavení</translation>
    </message>
    <message>
        <source>Default &amp;Format:</source>
        <translation type="obsolete">Výchozí &amp;formát:</translation>
    </message>
    <message>
        <source>Default &amp;Channels:</source>
        <translation type="obsolete">Výchozí &amp;kanály:</translation>
    </message>
    <message>
        <source>Default &amp;Sample Rate:</source>
        <translation type="obsolete">Výchozí &amp;vzorkovací kmitočet:</translation>
    </message>
    <message>
        <source>Default &amp;Bitrate:</source>
        <translation type="obsolete">Výchozí &amp;datový tok:</translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation type="obsolete">&amp;OK</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation type="obsolete">&amp;Zrušit</translation>
    </message>
    <message>
        <source>PCM16</source>
        <translation type="obsolete">PCM16</translation>
    </message>
    <message>
        <source>OggVorbis</source>
        <translation type="obsolete">OggVorbis</translation>
    </message>
    <message>
        <source>MPEG Layer 2</source>
        <translation type="obsolete">MPEG Layer 2</translation>
    </message>
    <message>
        <source>MPEG Layer 3</source>
        <translation type="obsolete">MPEG Layer 3</translation>
    </message>
</context>
<context>
    <name>RDButtonDialog</name>
    <message>
        <source>Edit Button</source>
        <translation>Upravit tlačítko</translation>
    </message>
    <message>
        <source>Label:</source>
        <translation>Štítek:</translation>
    </message>
    <message>
        <source>Cart:</source>
        <translation>Vozík:</translation>
    </message>
    <message>
        <source>Set
Cart</source>
        <translation>Nastavit
vozík</translation>
    </message>
    <message>
        <source>Clear</source>
        <translation>Smazat</translation>
    </message>
    <message>
        <source>Set
Color</source>
        <translation>Nastavit
barvu</translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation>&amp;OK</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation>&amp;Zrušit</translation>
    </message>
    <message>
        <source>NOT FOUND</source>
        <translation>NENALEZENO</translation>
    </message>
</context>
<context>
    <name>RDCardSelector</name>
    <message>
        <source>Card:</source>
        <translation>Karta:</translation>
    </message>
    <message>
        <source>Port:</source>
        <translation>Přípojka:</translation>
    </message>
</context>
<context>
    <name>RDCart</name>
    <message>
        <source>Sequentially</source>
        <translation type="obsolete">Sequentiell</translation>
    </message>
    <message>
        <source>Randomly</source>
        <translation type="obsolete">Zufällig</translation>
    </message>
    <message>
        <source>Unknown</source>
        <translation type="obsolete">Unbekannt</translation>
    </message>
    <message>
        <source>Feature</source>
        <translation type="obsolete">Feature</translation>
    </message>
    <message>
        <source>Theme Open</source>
        <translation type="obsolete">Thema Anfang</translation>
    </message>
    <message>
        <source>Theme Close</source>
        <translation type="obsolete">Thema Ende</translation>
    </message>
    <message>
        <source>Theme Open/Close</source>
        <translation type="obsolete">Thema Anfang/Ende</translation>
    </message>
    <message>
        <source>Background</source>
        <translation type="obsolete">Hintergrund</translation>
    </message>
    <message>
        <source>Commercial/Jingle/Promo</source>
        <translation type="obsolete">Commercial/Jingle/Promo</translation>
    </message>
</context>
<context>
    <name>RDCartDialog</name>
    <message>
        <source>Select Cart</source>
        <translation>Vybrat vozík</translation>
    </message>
    <message>
        <source>Please Wait...</source>
        <translation>Počkejte, prosím...</translation>
    </message>
    <message>
        <source>Cart Filter:</source>
        <translation>Filtr vozíku:</translation>
    </message>
    <message>
        <source>&amp;Search</source>
        <translation>&amp;Hledat</translation>
    </message>
    <message>
        <source>C&amp;lear</source>
        <translation>S&amp;mazat</translation>
    </message>
    <message>
        <source>Group:</source>
        <translation>Skupina:</translation>
    </message>
    <message>
        <source>NUMBER</source>
        <translation type="obsolete">ČÍSLO</translation>
    </message>
    <message>
        <source>LENGTH</source>
        <translation type="obsolete">DÉLKA</translation>
    </message>
    <message>
        <source>TITLE</source>
        <translation type="obsolete">NÁZEV</translation>
    </message>
    <message>
        <source>ARTIST</source>
        <translation type="obsolete">UMĚLEC</translation>
    </message>
    <message>
        <source>GROUP</source>
        <translation type="obsolete">SKUPINA</translation>
    </message>
    <message>
        <source>CLIENT</source>
        <translation type="obsolete">ZÁKAZNÍK</translation>
    </message>
    <message>
        <source>AGENCY</source>
        <translation type="obsolete">AGENTURA</translation>
    </message>
    <message>
        <source>USER DEF</source>
        <translation type="obsolete">DEF UŽIVATELE</translation>
    </message>
    <message>
        <source>START</source>
        <translation type="obsolete">ZAČÁTEK</translation>
    </message>
    <message>
        <source>END</source>
        <translation type="obsolete">KONEC</translation>
    </message>
    <message>
        <source>Send to
&amp;Editor</source>
        <translation>Poslat do
&amp;editoru</translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation>&amp;OK</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation>&amp;Zrušit</translation>
    </message>
    <message>
        <source>ALL</source>
        <translation>VŠE</translation>
    </message>
    <message>
        <source>Show Only First</source>
        <translation>Ukázat pouze první </translation>
    </message>
    <message>
        <source>Matches</source>
        <translation>Shody</translation>
    </message>
    <message>
        <source>Scheduler Code:</source>
        <translation>Kódy rozvrhovače:</translation>
    </message>
    <message>
        <source>Load From
&amp;File</source>
        <translation>Nahrát
ze &amp;souboru</translation>
    </message>
    <message>
        <source>Cart Error</source>
        <translation>Chyba vozíku</translation>
    </message>
    <message>
        <source>Unable to create temporary cart for import!</source>
        <translation>Nelze vytvořit dočasný vozík pro zavedení!</translation>
    </message>
    <message>
        <source>Unable to get temporary cart number for import!</source>
        <translation type="obsolete">Nelze získat číslo dočasného vozík pro zavedení!</translation>
    </message>
    <message>
        <source>Import Error</source>
        <translation>Chyba při zavedení</translation>
    </message>
    <message>
        <source>Imported from</source>
        <translation>Zavedeno z</translation>
    </message>
    <message>
        <source>Importing...</source>
        <translation>Zavádí se...</translation>
    </message>
    <message>
        <source>Importing</source>
        <translation>Zavádí se</translation>
    </message>
    <message>
        <source>Number</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Length</source>
        <translation type="unfinished">Délka</translation>
    </message>
    <message>
        <source>Title</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Artist</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Group</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Composer</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Conductor</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Client</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Agency</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>User Def</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Start</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>End</source>
        <translation type="unfinished">Konec</translation>
    </message>
</context>
<context>
    <name>RDCddbLookup</name>
    <message>
        <source>CDDB Query</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Multiple Matches Found!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>OK</source>
        <translation type="unfinished">OK</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation type="unfinished">Zrušit</translation>
    </message>
</context>
<context>
    <name>RDCueEdit</name>
    <message>
        <source>Start</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>End</source>
        <translation type="unfinished">Konec</translation>
    </message>
    <message>
        <source>&amp;Recue</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>RDCueEditDialog</name>
    <message>
        <source>Set Cue Point</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation type="unfinished">&amp;OK</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation type="unfinished">&amp;Zrušit</translation>
    </message>
</context>
<context>
    <name>RDCutDialog</name>
    <message>
        <source>Select Cut</source>
        <translation>Vybrat záběr</translation>
    </message>
    <message>
        <source>Please Wait...</source>
        <translation>Počkejte, prosím...</translation>
    </message>
    <message>
        <source>Cart Filter:</source>
        <translation>Filtr vozíku:</translation>
    </message>
    <message>
        <source>&amp;Search</source>
        <translation>&amp;Hledat</translation>
    </message>
    <message>
        <source>C&amp;lear</source>
        <translation>S&amp;mazat</translation>
    </message>
    <message>
        <source>Group:</source>
        <translation>Skupina:</translation>
    </message>
    <message>
        <source>Carts</source>
        <translation>Vozíky</translation>
    </message>
    <message>
        <source>NUMBER</source>
        <translation type="obsolete">ČÍSLO</translation>
    </message>
    <message>
        <source>TITLE</source>
        <translation type="obsolete">NÁZEV</translation>
    </message>
    <message>
        <source>GROUP</source>
        <translation type="obsolete">SKUPINA</translation>
    </message>
    <message>
        <source>Cuts</source>
        <translation>Záběry</translation>
    </message>
    <message>
        <source>DESCRIPTION</source>
        <translation type="obsolete">POPIS</translation>
    </message>
    <message>
        <source>&amp;Add New
Cart</source>
        <translation>&amp;Přidat nový
vozík</translation>
    </message>
    <message>
        <source>&amp;Clear</source>
        <translation>&amp;Smazat</translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation>&amp;OK</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation>&amp;Zrušit</translation>
    </message>
    <message>
        <source>ALL</source>
        <translation>VŠE</translation>
    </message>
    <message>
        <source>Show Only First</source>
        <translation>Ukázat pouze první </translation>
    </message>
    <message>
        <source>Matches</source>
        <translation>Shody</translation>
    </message>
    <message>
        <source>Scheduler Code:</source>
        <translation>Kódy rozvrhovače:</translation>
    </message>
    <message>
        <source>Number</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Title</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Group</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Description</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>RDDateDialog</name>
    <message>
        <source>Select Date</source>
        <translation>Vybrat datum</translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation>&amp;OK</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation>&amp;Zrušit</translation>
    </message>
</context>
<context>
    <name>RDDatePicker</name>
    <message>
        <source>Mo</source>
        <translation>Po</translation>
    </message>
    <message>
        <source>Tu</source>
        <translation>Út</translation>
    </message>
    <message>
        <source>We</source>
        <translation>St</translation>
    </message>
    <message>
        <source>Th</source>
        <translation>Čt</translation>
    </message>
    <message>
        <source>Fr</source>
        <translation>Pá</translation>
    </message>
    <message>
        <source>Sa</source>
        <translation>So</translation>
    </message>
    <message>
        <source>Su</source>
        <translation>Ne</translation>
    </message>
</context>
<context>
    <name>RDEditAudio</name>
    <message>
        <source>&amp;Save</source>
        <translation>&amp;Uložit</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation>&amp;Zrušit</translation>
    </message>
    <message>
        <source>Amplitude</source>
        <translation>Rozkmit</translation>
    </message>
    <message>
        <source>Zoom
In</source>
        <translation type="obsolete">Přiblížit</translation>
    </message>
    <message>
        <source>Zoom
Out</source>
        <translation type="obsolete">Oddálit</translation>
    </message>
    <message>
        <source>Time</source>
        <translation>Čas</translation>
    </message>
    <message>
        <source>Full
In</source>
        <translation>Plný
In</translation>
    </message>
    <message>
        <source>Full
Out</source>
        <translation>Plný
Out</translation>
    </message>
    <message>
        <source>Goto</source>
        <translation>Přejít na</translation>
    </message>
    <message>
        <source>Cursor</source>
        <translation>Ukazovátko</translation>
    </message>
    <message>
        <source>Home</source>
        <translation>Domov</translation>
    </message>
    <message>
        <source>End</source>
        <translation>Konec</translation>
    </message>
    <message>
        <source>Cut
Start</source>
        <translation>Začátek
záběru</translation>
    </message>
    <message>
        <source>Cut
End</source>
        <translation>Konec
záběru</translation>
    </message>
    <message>
        <source>Talk
Start</source>
        <translation>Začátek
hovoru</translation>
    </message>
    <message>
        <source>Segue
Start</source>
        <translation>Začátek
přechodu</translation>
    </message>
    <message>
        <source>Segue
End</source>
        <translation>Konec
přechodu</translation>
    </message>
    <message>
        <source>Fade
Up</source>
        <translation>Utichat</translation>
    </message>
    <message>
        <source>Hook
Start</source>
        <translation>Začátek
chytlavé melodie</translation>
    </message>
    <message>
        <source>Hook
End</source>
        <translation>Konec
chytlavé melodie</translation>
    </message>
    <message>
        <source> dB</source>
        <translation> dB</translation>
    </message>
    <message>
        <source>Threshold</source>
        <translation>Prahová hodnota</translation>
    </message>
    <message>
        <source>Trim
Start</source>
        <translation>Začátek
ustřižení</translation>
    </message>
    <message>
        <source>Trim
End</source>
        <translation>Konec
ustřižení</translation>
    </message>
    <message>
        <source>Cut Gain</source>
        <translation>Zesílení záběru</translation>
    </message>
    <message>
        <source>Remove
Marker</source>
        <translation>Odstranit
značku</translation>
    </message>
    <message>
        <source>No Fade on Segue Out</source>
        <translation>Žádné prolínání při přechodu ven</translation>
    </message>
    <message>
        <source>Position</source>
        <translation>Poloha</translation>
    </message>
    <message>
        <source>Length</source>
        <translation>Délka</translation>
    </message>
    <message>
        <source>Delete Talk Markers</source>
        <translation>Smazat značky hovoru</translation>
    </message>
    <message>
        <source>Delete Segue Markers</source>
        <translation>Smazat značky přechodu</translation>
    </message>
    <message>
        <source>Delete Hook Markers</source>
        <translation>Smazat značky háčku (hook)</translation>
    </message>
    <message>
        <source>Delete Fade Up Marker</source>
        <translation>Smazat značku zesílení</translation>
    </message>
    <message>
        <source>Delete Fade Down Marker</source>
        <translation>Smazat značku zeslabení</translation>
    </message>
    <message>
        <source>dB</source>
        <translation>dB</translation>
    </message>
    <message>
        <source>&lt;none&gt;</source>
        <translation>&lt;none&gt;</translation>
    </message>
    <message>
        <source>Cut</source>
        <translation>Záběr</translation>
    </message>
    <message>
        <source>Talk</source>
        <translation>Hovor</translation>
    </message>
    <message>
        <source>Segue</source>
        <translation>Přechod</translation>
    </message>
    <message>
        <source>Hook</source>
        <translation>Chytlavá melodie</translation>
    </message>
    <message>
        <source>Fade Up</source>
        <translation>Zesílit</translation>
    </message>
    <message>
        <source>Fade Down</source>
        <translation>Zeslabit</translation>
    </message>
    <message>
        <source>L</source>
        <translation>L</translation>
    </message>
    <message>
        <source>R</source>
        <translation>P</translation>
    </message>
    <message>
        <source>Rivendell Web Service</source>
        <translation>Internetová služba Rivendellu</translation>
    </message>
    <message>
        <source>Unable to download peak data, error was:
&quot;</source>
        <translation>Nepodařilo se stáhnout data vrcholu. Chyba byla:
&quot;</translation>
    </message>
    <message>
        <source>Edit Audio</source>
        <translation>Upravit zvuk</translation>
    </message>
    <message>
        <source>Marker Warning</source>
        <translation>Varování týkající se značek</translation>
    </message>
    <message>
        <source>Less than half of the audio is playable with these marker settings.
Are you sure you want to save?</source>
        <translation>Méně než polovina zvukového záznamu je přehratelná s těmito nastaveními pro značky.
Opravdu chcete uložit?</translation>
    </message>
    <message>
        <source>More than half of the audio will be faded with these marker settings.
Are you sure you want to save?</source>
        <translation>Více než polovina zvukového záznamu bude s těmito nastaveními pro značky vystřižena.
Opravdu chcete uložit?</translation>
    </message>
</context>
<context>
    <name>RDEditPanelName</name>
    <message>
        <source>Edit Panel Name</source>
        <translation>Upravit název panelu</translation>
    </message>
    <message>
        <source>Panel &amp;Name:</source>
        <translation>&amp;Název panelu:</translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation>&amp;OK</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation>&amp;Zrušit</translation>
    </message>
</context>
<context>
    <name>RDExceptionDialog</name>
    <message>
        <source>Rivendell Exception Report</source>
        <translation type="obsolete">Zpráva o chybě Rivendellu</translation>
    </message>
    <message>
        <source>&amp;Save</source>
        <translation type="obsolete">&amp;Uložit</translation>
    </message>
    <message>
        <source>&amp;Close</source>
        <translation type="obsolete">&amp;Zavřít</translation>
    </message>
    <message>
        <source>Text (*.txt *.TXT)
All Files (*.*)</source>
        <translation type="obsolete">Text (*.txt *.TXT)
Všechny soubory (*.*)</translation>
    </message>
    <message>
        <source>Export File</source>
        <translation type="obsolete">Vyvést soubor</translation>
    </message>
    <message>
        <source>The file</source>
        <translation type="obsolete">Soubor</translation>
    </message>
    <message>
        <source>already exists!
Overwrite?</source>
        <translation type="obsolete">Již existuje!
Přepsat?</translation>
    </message>
    <message>
        <source>File Exists</source>
        <translation type="obsolete">Soubor již existuje</translation>
    </message>
    <message>
        <source>Unable to open file</source>
        <translation type="obsolete">Nelze otevřít soubor</translation>
    </message>
    <message>
        <source>for writing!</source>
        <translation type="obsolete">pro zápis!</translation>
    </message>
    <message>
        <source>File Error</source>
        <translation type="obsolete">Chyba souboru</translation>
    </message>
</context>
<context>
    <name>RDExportSettingsDialog</name>
    <message>
        <source>Edit Export Settings</source>
        <translation>Upravit nastavení uložení v jiném formátu</translation>
    </message>
    <message>
        <source>&amp;Channels:</source>
        <translation>&amp;Kanály:</translation>
    </message>
    <message>
        <source>&amp;Sample Rate:</source>
        <translation>&amp;Vzorkovací kmitočet:</translation>
    </message>
    <message>
        <source>&amp;Bitrate:</source>
        <translation>&amp;Datový tok:</translation>
    </message>
    <message>
        <source>&amp;Quality:</source>
        <translation>&amp;Kvalita:</translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation>&amp;OK</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation>&amp;Zrušit</translation>
    </message>
    <message>
        <source>PCM16</source>
        <translation>PCM16</translation>
    </message>
    <message>
        <source>FLAC</source>
        <translation>FLAC</translation>
    </message>
    <message>
        <source>MPEG Layer 2</source>
        <translation>MPEG Layer 2</translation>
    </message>
    <message>
        <source>MPEG Layer 3</source>
        <translation>MPEG Layer 3</translation>
    </message>
    <message>
        <source>OggVorbis</source>
        <translation>OggVorbis</translation>
    </message>
    <message>
        <source>VBR</source>
        <translation>VBR</translation>
    </message>
    <message>
        <source>32 kbps</source>
        <translation>32 kb/s</translation>
    </message>
    <message>
        <source>64 kbps</source>
        <translation>64 kb/s</translation>
    </message>
    <message>
        <source>96 kbps</source>
        <translation>96 kb/s</translation>
    </message>
    <message>
        <source>128 kbps</source>
        <translation>128 kb/s</translation>
    </message>
    <message>
        <source>160 kbps</source>
        <translation>160 kb/s</translation>
    </message>
    <message>
        <source>192 kbps</source>
        <translation>192 kb/s</translation>
    </message>
    <message>
        <source>224 kbps</source>
        <translation>224 kb/s</translation>
    </message>
    <message>
        <source>256 kbps</source>
        <translation>256 kb/s</translation>
    </message>
    <message>
        <source>288 kbps</source>
        <translation>288 kb/s</translation>
    </message>
    <message>
        <source>320 kbps</source>
        <translation>320 kb/s</translation>
    </message>
    <message>
        <source>352 kbps</source>
        <translation>352 kb/s</translation>
    </message>
    <message>
        <source>384 kbps</source>
        <translation>384 kb/s</translation>
    </message>
    <message>
        <source>416 kbps</source>
        <translation>416 kb/s</translation>
    </message>
    <message>
        <source>448 kbps</source>
        <translation>448 kb/s</translation>
    </message>
    <message>
        <source>48 kbps</source>
        <translation>48 kb/s</translation>
    </message>
    <message>
        <source>56 kbps</source>
        <translation>56 kb/s</translation>
    </message>
    <message>
        <source>80 kbps</source>
        <translation>80 kb/s</translation>
    </message>
    <message>
        <source>112 kbps</source>
        <translation>112 kb/s</translation>
    </message>
    <message>
        <source>40 kbps</source>
        <translation>40 kb/s</translation>
    </message>
    <message>
        <source>8 kbps</source>
        <translation>8 kb/s</translation>
    </message>
    <message>
        <source>16 kbps</source>
        <translation>16 kb/s</translation>
    </message>
    <message>
        <source>24 kbps</source>
        <translation>24 kb/s</translation>
    </message>
    <message>
        <source>144 kbps</source>
        <translation>144 kb/s</translation>
    </message>
    <message>
        <source>PCM24</source>
        <translation type="unfinished">PCM24</translation>
    </message>
</context>
<context>
    <name>RDGetAth</name>
    <message>
        <source>Enter ATH</source>
        <translation>Zadat ATH</translation>
    </message>
    <message>
        <source>Enter the agreggate tuning hours (ATH)
figure for the report period.
(Supplied by your streaming provider).</source>
        <translation>Zadejte údaj agreggate tuning hours (ATH)
pro dobu zprávy.
(Zeptejte se na to svého poskytovatele proudu - stream).</translation>
    </message>
    <message>
        <source>ATH:</source>
        <translation>ATH:</translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation>&amp;OK</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation>&amp;Zrušit</translation>
    </message>
    <message>
        <source>Invalid ATH</source>
        <translation>Neplatný údaj ATH</translation>
    </message>
    <message>
        <source>You must provide a valid ATH figure!</source>
        <translation>Musíte zadat platný údaj ATH!</translation>
    </message>
</context>
<context>
    <name>RDGetPasswd</name>
    <message>
        <source>Enter Password</source>
        <translation>Zadat heslo</translation>
    </message>
    <message>
        <source>Enter password</source>
        <translation>Zadat heslo</translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation>&amp;OK</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation>&amp;Zrušit</translation>
    </message>
</context>
<context>
    <name>RDGpioSelector</name>
    <message>
        <source>Pin:</source>
        <translation>PIN:</translation>
    </message>
</context>
<context>
    <name>RDImportAudio</name>
    <message>
        <source>Import/Export Audio File</source>
        <translation>Zavést/Vyvést soubor se zvukem</translation>
    </message>
    <message>
        <source>Import File</source>
        <translation>Zavést soubor</translation>
    </message>
    <message>
        <source>Filename:</source>
        <translation>Název souboru:</translation>
    </message>
    <message>
        <source>&amp;Select</source>
        <translation>&amp;Vybrat</translation>
    </message>
    <message>
        <source>Import file metadata</source>
        <translation>Zavést popisná data souboru</translation>
    </message>
    <message>
        <source>Channels:</source>
        <translation>Kanály:</translation>
    </message>
    <message>
        <source>Autotrim</source>
        <translation>Automatické zastřižení</translation>
    </message>
    <message>
        <source>Level:</source>
        <translation>Úroveň:</translation>
    </message>
    <message>
        <source>dBFS</source>
        <translation>dbFS</translation>
    </message>
    <message>
        <source>Export File</source>
        <translation>Vyvést soubor</translation>
    </message>
    <message>
        <source>Export file metadata</source>
        <translation>Vyvést popisná data souboru</translation>
    </message>
    <message>
        <source>Format:</source>
        <translation>Formát:</translation>
    </message>
    <message>
        <source>S&amp;et</source>
        <translation>&amp;Nastavit</translation>
    </message>
    <message>
        <source>Normalize</source>
        <translation>Normalizovat</translation>
    </message>
    <message>
        <source>&amp;Import</source>
        <translation>&amp;Zavést</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation>&amp;Zrušit</translation>
    </message>
    <message>
        <source>Export</source>
        <translation>Vyvést</translation>
    </message>
    <message>
        <source>Import</source>
        <translation>Zavést</translation>
    </message>
    <message>
        <source>Import Audio File</source>
        <translation>Zavést zvukový soubor</translation>
    </message>
    <message>
        <source>File does not exist!</source>
        <translation>Soubor neexistuje!</translation>
    </message>
    <message>
        <source>Cannot open file!</source>
        <translation type="obsolete">Kann die Datei nicht öffnen!</translation>
    </message>
    <message>
        <source>Unsupported file type!</source>
        <translation type="obsolete">Dateityp nicht unterstützt!</translation>
    </message>
    <message>
        <source>Audio Exists</source>
        <translation type="obsolete">Audiomaterial existiert</translation>
    </message>
    <message>
        <source>This will overwrite the existing recording.
Do you want to proceed?</source>
        <translation type="obsolete">Das wird die existierende Aufnahme löschen.
Wollen sie fortfahren?</translation>
    </message>
    <message>
        <source>Empty Clipboard</source>
        <translation type="obsolete">Zwischenablage leeren</translation>
    </message>
    <message>
        <source>Importing this cut will also empty the clipboard.
Do you still want to proceed?</source>
        <translation type="obsolete">Diesen Cut zu importieren wird die Zwischen-
ablage löschen! Fortfahren?</translation>
    </message>
    <message>
        <source>Import Complete</source>
        <translation>Zavedení dokončeno</translation>
    </message>
    <message>
        <source>Import complete!</source>
        <translation>Zavedení dokončeno!</translation>
    </message>
    <message>
        <source>Import Aborted</source>
        <translation type="obsolete">Import abgebrochen</translation>
    </message>
    <message>
        <source>The import has been aborted.</source>
        <translation type="obsolete">Der Import wurde abgebrochen.</translation>
    </message>
    <message>
        <source>Import Failed</source>
        <translation type="obsolete">Import fehlgeschlagen</translation>
    </message>
    <message>
        <source>The importer encountered an error.
Please check your importer configuration and try again.</source>
        <translation type="obsolete">Der Importer ist auf einen Fehler gestoßen.
Bitte überprüfen sie die Importer-Einstellungen und versuchen sie es erneut.</translation>
    </message>
    <message>
        <source>File Exists</source>
        <translation>Soubor již existuje</translation>
    </message>
    <message>
        <source>The selected file already exists!
Do you want to overwrite it?</source>
        <translation>Vybraný soubor již existuje!
Chcete jej přepsat?</translation>
    </message>
    <message>
        <source>File Error</source>
        <translation type="obsolete">Dateifehler</translation>
    </message>
    <message>
        <source>Cannot open file in archive!</source>
        <translation type="obsolete">Kann die Datei im Archiv nicht öffnen!</translation>
    </message>
    <message>
        <source>Unsupported file type in archive!</source>
        <translation type="obsolete">Nicht unterstützter Dateityp im Archiv!</translation>
    </message>
    <message>
        <source>No Access</source>
        <translation type="obsolete">Kein Zugriff</translation>
    </message>
    <message>
        <source>Unable to open the file for writing!</source>
        <translation type="obsolete">Kann die Logdatei nicht zum schreiben öffnen!</translation>
    </message>
    <message>
        <source>OK</source>
        <translation type="obsolete">OK</translation>
    </message>
    <message>
        <source>Export Complete</source>
        <translation>Vyvedení dokončeno</translation>
    </message>
    <message>
        <source>Export complete!</source>
        <translation>Vyvedení dokončeno!</translation>
    </message>
    <message>
        <source>Export Aborted</source>
        <translation type="obsolete">Export abgebrochen</translation>
    </message>
    <message>
        <source>The export has been aborted.</source>
        <translation type="obsolete">Der Export wurde abgebrochen.</translation>
    </message>
    <message>
        <source>Export Failed</source>
        <translation type="obsolete">Export fehlgeschlagen</translation>
    </message>
    <message>
        <source>The Exporter encountered an error.
Please check your configuration and try again.</source>
        <translation type="obsolete">Der Exporter ist auf einen Fehler gestoßen.
Bitte Kofiguration prüfen und erneut versuchen.</translation>
    </message>
    <message>
        <source>Export Error</source>
        <translation>Chyba při vyvedení</translation>
    </message>
    <message>
        <source>Import Error</source>
        <translation>Chyba při zavedení</translation>
    </message>
    <message>
        <source>Abort</source>
        <translation>Zrušit</translation>
    </message>
</context>
<context>
    <name>RDIntegerDialog</name>
    <message>
        <source>&amp;OK</source>
        <translation type="obsolete">&amp;OK</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation type="obsolete">&amp;Zrušit</translation>
    </message>
    <message>
        <source>Set Value</source>
        <translation type="obsolete">Nastavit hodnotu</translation>
    </message>
</context>
<context>
    <name>RDIntegerEdit</name>
    <message>
        <source>Add</source>
        <translation type="obsolete">Přidat</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation type="obsolete">Smazat</translation>
    </message>
    <message>
        <source>Set Value</source>
        <translation type="obsolete">Nastavit hodnotu</translation>
    </message>
</context>
<context>
    <name>RDLicense</name>
    <message>
        <source>&amp;Close</source>
        <translation type="obsolete">&amp;Zavřít</translation>
    </message>
    <message>
        <source>GNU Public License v2</source>
        <translation type="obsolete">GNU Public License v2</translation>
    </message>
</context>
<context>
    <name>RDListGroups</name>
    <message>
        <source>Select Group</source>
        <translation>Vybrat skupinu</translation>
    </message>
    <message>
        <source>NAME</source>
        <translation>NÁZEV</translation>
    </message>
    <message>
        <source>DESCRIPTION</source>
        <translation>POPIS</translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation>&amp;OK</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation>&amp;Zrušit</translation>
    </message>
</context>
<context>
    <name>RDListLogs</name>
    <message>
        <source>Select Log - User: </source>
        <translation type="obsolete">Vybrat zápis - uživatel:</translation>
    </message>
    <message>
        <source>Select Log</source>
        <translation type="unfinished">Vybrat zápis</translation>
    </message>
    <message>
        <source>NAME</source>
        <translation type="obsolete">NÁZEV</translation>
    </message>
    <message>
        <source>DESCRIPTION</source>
        <translation type="obsolete">POPIS</translation>
    </message>
    <message>
        <source>SERVICE</source>
        <translation type="obsolete">SLUŽBA</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>OK</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Zrušit</translation>
    </message>
    <message>
        <source>Name</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Description</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Service</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>RDListSelector</name>
    <message>
        <source>Available Services</source>
        <translation>Dostupné služby</translation>
    </message>
    <message>
        <source>Add &gt;&gt;</source>
        <translation>Přidat &gt;&gt;</translation>
    </message>
    <message>
        <source>&lt;&lt; Remove</source>
        <translation>&lt;&lt; Odstranit</translation>
    </message>
    <message>
        <source>Active Services</source>
        <translation>Spuštěné služby</translation>
    </message>
</context>
<context>
    <name>RDLogFilter</name>
    <message>
        <source>Service</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Filter</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Clear</source>
        <translation type="unfinished">Smazat</translation>
    </message>
    <message>
        <source>Show Only Recent Logs</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>ALL</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>RDLogLine</name>
    <message>
        <source>Unknown</source>
        <translation type="obsolete">Unbekannt</translation>
    </message>
    <message>
        <source>Manual</source>
        <translation type="obsolete">Handbuch</translation>
    </message>
    <message>
        <source>Play</source>
        <translation type="obsolete">Play</translation>
    </message>
    <message>
        <source>Segue</source>
        <translation type="obsolete">Segue</translation>
    </message>
    <message>
        <source>Time</source>
        <translation type="obsolete">Zeit</translation>
    </message>
    <message>
        <source>Panel</source>
        <translation type="obsolete">Panel</translation>
    </message>
    <message>
        <source>Macro</source>
        <translation type="obsolete">Makro</translation>
    </message>
    <message>
        <source>PLAY</source>
        <translation type="obsolete">PLAY</translation>
    </message>
    <message>
        <source>SEGUE</source>
        <translation type="obsolete">SEGUE</translation>
    </message>
    <message>
        <source>STOP</source>
        <translation type="obsolete">STOP</translation>
    </message>
    <message>
        <source>UNKNOWN</source>
        <translation type="obsolete">UNBEKANNT</translation>
    </message>
    <message>
        <source>Audio</source>
        <translation type="obsolete">Audio</translation>
    </message>
    <message>
        <source>Marker</source>
        <translation type="obsolete">Marker</translation>
    </message>
    <message>
        <source>Open Bracket</source>
        <translation type="obsolete">Klammer öffnen</translation>
    </message>
    <message>
        <source>Close Bracket</source>
        <translation type="obsolete">Klammer schließen</translation>
    </message>
    <message>
        <source>ChainTo</source>
        <translation type="obsolete">ChainTo</translation>
    </message>
    <message>
        <source>Track</source>
        <translation type="obsolete">Track</translation>
    </message>
    <message>
        <source>Link</source>
        <translation type="obsolete">Link</translation>
    </message>
    <message>
        <source>Traffic</source>
        <translation type="obsolete">Traffic</translation>
    </message>
    <message>
        <source>Music</source>
        <translation type="obsolete">Musik</translation>
    </message>
    <message>
        <source>RDLogManager</source>
        <translation type="obsolete">RDLogManager</translation>
    </message>
    <message>
        <source>Tracker</source>
        <translation type="obsolete">Tracker</translation>
    </message>
</context>
<context>
    <name>RDPanelButton</name>
    <message>
        <source>No Audio</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>RDPasswd</name>
    <message>
        <source>Change Password</source>
        <translation>Změnit heslo</translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation>&amp;OK</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation>&amp;Zrušit</translation>
    </message>
    <message>
        <source>&amp;Password:</source>
        <translation>He&amp;slo:</translation>
    </message>
    <message>
        <source>C&amp;onfirm:</source>
        <translation>&amp;Potvrdit:</translation>
    </message>
    <message>
        <source>Password Mismatch</source>
        <translation>Dvojice hesel se neshodují</translation>
    </message>
    <message>
        <source>The passwords don&apos;t match,
please try again!</source>
        <translation>Hesla se neshodují.
Zkuste to, prosím, znovu!</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>OK</translation>
    </message>
</context>
<context>
    <name>RDProcess</name>
    <message>
        <source>no such program</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>ok</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>process crashed</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>process returned exit code</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>RDRecording</name>
    <message>
        <source>Recording</source>
        <translation type="obsolete">Aufnahme</translation>
    </message>
    <message>
        <source>Macro Event</source>
        <translation type="obsolete">Makro Event</translation>
    </message>
    <message>
        <source>Switch Event</source>
        <translation type="obsolete">Schalt-Event</translation>
    </message>
    <message>
        <source>Playout</source>
        <translation type="obsolete">Playout</translation>
    </message>
    <message>
        <source>Download</source>
        <translation type="obsolete">Download</translation>
    </message>
    <message>
        <source>Upload</source>
        <translation type="obsolete">Upload</translation>
    </message>
    <message>
        <source>Ok</source>
        <translation type="obsolete">Ok</translation>
    </message>
    <message>
        <source>Short Length</source>
        <translation type="obsolete">Kurze Länge</translation>
    </message>
    <message>
        <source>Low Level</source>
        <translation type="obsolete">Niedriger Level</translation>
    </message>
    <message>
        <source>High Level</source>
        <translation type="obsolete">Hoher Level</translation>
    </message>
    <message>
        <source>Downloading</source>
        <translation type="obsolete">Herunterladen</translation>
    </message>
    <message>
        <source>Uploading</source>
        <translation type="obsolete">Hochladen</translation>
    </message>
    <message>
        <source>Server Error</source>
        <translation type="obsolete">Serverfehler</translation>
    </message>
    <message>
        <source>Internal Error</source>
        <translation type="obsolete">Interner Fehler</translation>
    </message>
    <message>
        <source>Interrupted</source>
        <translation type="obsolete">Unterbrochen</translation>
    </message>
    <message>
        <source>Playing</source>
        <translation type="obsolete">Abspielen</translation>
    </message>
    <message>
        <source>Waiting</source>
        <translation type="obsolete">Warten</translation>
    </message>
    <message>
        <source>Device Busy</source>
        <translation type="obsolete">Gerät beschäftigt</translation>
    </message>
    <message>
        <source>No Such Cart/Cut</source>
        <translation type="obsolete">Kein solcher Cart/Cut</translation>
    </message>
    <message>
        <source>Unknown Audio Format</source>
        <translation type="obsolete">Unbekanntes Audioformat</translation>
    </message>
</context>
<context>
    <name>RDRehash</name>
    <message>
        <source>OK</source>
        <translation type="unfinished">OK</translation>
    </message>
    <message>
        <source>Internal Error</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Invalid URL</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>RDXport service returned an error</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Invalid user or password</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Audio does not exist</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>RDRenderer</name>
    <message>
        <source>no such cart</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>no such cut</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Using temporary file</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Pass 2 of 2</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Writing output file</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Pass 1 of 1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Pass 1 of 2</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Importing cart</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>first-time event not found</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>last-time event not found</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>STOP</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>FAIL</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>NO AUDIO AVAILABLE</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>SKIP</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>--- end of log ---</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>unable to open output file</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>log render halted at line</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>due to STOP</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>at line</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>failed to play (NO AUDIO AVAILABLE)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Rendered log is too long!</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>RDReport</name>
    <message>
        <source>CBSI DeltaFlex Traffic Reconciliation v2.01</source>
        <translation type="obsolete">CBSI DeltaFlex Traffic Reconciliation v2.01</translation>
    </message>
    <message>
        <source>Text Log</source>
        <translation type="obsolete">Text Log</translation>
    </message>
    <message>
        <source>ASCAP/BMI Electronic Music Report</source>
        <translation type="obsolete">ASCAP/BMI Electronic Music Report</translation>
    </message>
    <message>
        <source>Technical Playout Report</source>
        <translation type="obsolete">Technical Playout Report</translation>
    </message>
    <message>
        <source>SoundExchange Statutory License Report</source>
        <translation type="obsolete">SoundExchange Statutory License Report</translation>
    </message>
    <message>
        <source>Unknown</source>
        <translation type="obsolete">Unbekannt</translation>
    </message>
    <message>
        <source>Other</source>
        <translation type="obsolete">Andere</translation>
    </message>
    <message>
        <source>AM</source>
        <translation type="obsolete">AM</translation>
    </message>
    <message>
        <source>FM</source>
        <translation type="obsolete">FM</translation>
    </message>
    <message>
        <source>Report complete!</source>
        <translation type="obsolete">Report vollständig!</translation>
    </message>
    <message>
        <source>Report canceled!</source>
        <translation type="obsolete">Report abgebrochen!</translation>
    </message>
    <message>
        <source>Unable to open report file!</source>
        <translation type="obsolete">Kann Reportdatei nicht öffnen!</translation>
    </message>
    <message>
        <source>RadioTraffic.com Traffic Reconciliation</source>
        <translation type="obsolete">RadioTraffic.com Traffic Reconciliation</translation>
    </message>
    <message>
        <source>VisualTraffic Reconciliation</source>
        <translation type="obsolete">VisualTraffic Reconciliation</translation>
    </message>
    <message>
        <source>CounterPoint Traffic Reconciliation</source>
        <translation type="obsolete">CounterPoint Traffic Reconciliation</translation>
    </message>
    <message>
        <source>Music1 Reconciliation</source>
        <translation type="obsolete">Music1 Reconciliation</translation>
    </message>
</context>
<context>
    <name>RDSoundPanel</name>
    <message>
        <source>Play All</source>
        <translation>Přehrát vše</translation>
    </message>
    <message>
        <source>Play Hook</source>
        <translation>Přehrát chytlavou melodii</translation>
    </message>
    <message>
        <source>Reset</source>
        <translation>Nastavit znovu</translation>
    </message>
    <message>
        <source>All</source>
        <translation>Vše</translation>
    </message>
    <message>
        <source>Setup</source>
        <translation>Nastavení</translation>
    </message>
    <message>
        <source>Cart</source>
        <translation>Vozík</translation>
    </message>
    <message>
        <source>Panel</source>
        <translation>Panel</translation>
    </message>
</context>
<context>
    <name>RDSqlDatabaseStatus</name>
    <message>
        <source>Database connection restored.</source>
        <translation type="obsolete">Databázové spojení obnoveno.</translation>
    </message>
    <message>
        <source>Database connection failed : </source>
        <translation type="obsolete">Databázové spojení se nezdařilo:</translation>
    </message>
</context>
<context>
    <name>RDStereoMeter</name>
    <message>
        <source>L</source>
        <translation>L</translation>
    </message>
    <message>
        <source>R</source>
        <translation>P</translation>
    </message>
    <message>
        <source>CLIP</source>
        <translation>CLIP</translation>
    </message>
</context>
<context>
    <name>RDSvc</name>
    <message>
        <source>The following events were not placed:
</source>
        <translation>Následující události nebyly umístěny:</translation>
    </message>
    <message>
        <source>[unknown cart]</source>
        <translation>[neznámý vozík]</translation>
    </message>
    <message>
        <source>Event Fill Errors
</source>
        <translation>Chyba plnění události</translation>
    </message>
    <message>
        <source>Log in use by</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Import failed</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
